"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var util_shared_styles_1 = require("@atlaskit/util-shared-styles");
var defaultTheme_1 = require("./defaultTheme");
var codeContainerStyle = {
    top: util_shared_styles_1.akGridSize,
    left: '16px',
    position: 'relative'
};
var lineNumberContainerStyle = function (theme) { return ({
    'color': theme.lineNumberColor,
    'backgroundColor': theme.lineNumberBgColor,
    'padding': util_shared_styles_1.akGridSize,
    'float': 'left'
}); };
var codeBlockStyle = function (theme) { return ({
    'hljs': {
        'fontFamily': util_shared_styles_1.akCodeFontFamily,
        'fontSize': util_shared_styles_1.akFontSizeDefault,
        'background': theme.backgroundColor,
        'color': theme.textColor,
        'borderRadius': util_shared_styles_1.akBorderRadius,
        'display': 'block',
        'overflowX': 'auto'
    },
    'hljs-subst': {
        'color': theme.substringColor
    },
    'hljs-keyword': {
        'color': theme.keywordColor
    },
    'hljs-attribute': {
        'color': theme.attributeColor
    },
    'hljs-selector-tag': {
        'color': theme.selectorTagColor
    },
    'hljs-doctag': {
        'color': theme.docTagColor
    },
    'hljs-name': {
        'color': theme.nameColor
    },
    'hljs-built_in': {
        'color': theme.builtInColor
    },
    'hljs-literal': {
        'color': theme.literalColor
    },
    'hljs-bullet': {
        'color': theme.bulletColor
    },
    'hljs-code': {
        'color': theme.codeColor
    },
    'hljs-addition': {
        'color': theme.additionColor
    },
    'hljs-regexp': {
        'color': theme.regexpColor
    },
    'hljs-symbol': {
        'color': theme.symbolColor
    },
    'hljs-variable': {
        'color': theme.variableColor
    },
    'hljs-template-variable': {
        'color': theme.templateVariableColor
    },
    'hljs-link': {
        'color': theme.linkColor
    },
    'hljs-selector-attr': {
        'color': theme.selectorAttributeColor
    },
    'hljs-selector-pseudo': {
        'color': theme.selectorPseudoColor
    },
    'hljs-type': {
        'color': theme.typeColor
    },
    'hljs-string': {
        'color': theme.stringColor
    },
    'hljs-selector-id': {
        'color': theme.selectorIdColor
    },
    'hljs-selector-class': {
        'color': theme.selectorClassColor
    },
    'hljs-quote': {
        'color': theme.quoteColor
    },
    'hljs-template-tag': {
        'color': theme.templateTagColor
    },
    'hljs-deletion': {
        'color': theme.deletionColor
    },
    'hljs-title': {
        'color': theme.titleColor,
        'fontWeight': 'bold'
    },
    'hljs-section': {
        'color': theme.sectionColor,
        'fontWeight': 'bold'
    },
    'hljs-comment': {
        'color': theme.commentColor
    },
    'hljs-meta-keyword': {
        'color': theme.metaKeywordColor
    },
    'hljs-meta': {
        'color': theme.metaColor
    },
    'hljs-emphasis': {
        'fontStyle': 'italic'
    },
    'hljs-strong': {
        'fontWeight': 'bold'
    },
    'hljs-function': {
        'color': theme.functionColor
    },
    'hljs-number': {
        'color': theme.numberColor
    }
}); };
var inlineCodeStyle = function (theme) { return ({
    'hljs': {
        'fontFamily': util_shared_styles_1.akCodeFontFamily,
        'fontSize': util_shared_styles_1.akFontSizeDefault,
        'background': theme.backgroundColor,
        'color': theme.textColor,
        'borderRadius': util_shared_styles_1.akBorderRadius,
        'display': 'inline',
        'overflowX': 'auto',
        'padding': '2px 4px'
    }
}); };
function applyTheme(theme) {
    if (theme === void 0) { theme = {}; }
    var newTheme = tslib_1.__assign({}, defaultTheme_1.defaultColors, theme);
    return {
        lineNumberContainerStyle: lineNumberContainerStyle(newTheme),
        codeBlockStyle: codeBlockStyle(newTheme),
        inlineCodeStyle: tslib_1.__assign({}, codeBlockStyle(newTheme), inlineCodeStyle(newTheme)),
        codeContainerStyle: codeContainerStyle
    };
}
exports.applyTheme = applyTheme;
//# sourceMappingURL=themeBuilder.js.map